aboutsummaryrefslogtreecommitdiffstats
path: root/serd/serd.h
diff options
context:
space:
mode:
Diffstat (limited to 'serd/serd.h')
-rw-r--r--serd/serd.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/serd/serd.h b/serd/serd.h
index 1dd49c65..822b4b10 100644
--- a/serd/serd.h
+++ b/serd/serd.h
@@ -96,10 +96,12 @@ typedef struct {
SerdChunk fragment; ///< Fragment
} SerdURI;
-/** Return true iff @a utf8 is a relative URI string. */
+static const SerdURI SERD_URI_NULL = {{0,0},{0,0},{0,0},{0,0},{0,0},{0,0}};
+
+/** Return true iff @a utf8 starts with a valid URI scheme. */
SERD_API
bool
-serd_uri_string_is_relative(const uint8_t* utf8);
+serd_uri_string_has_scheme(const uint8_t* utf8);
/** Parse @a utf8, writing result to @a out. */
SERD_API